==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/OrgTechnicalContactType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactTypeLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Org technical contact
 */
@ApiModel(description = "Org technical contact")
@JsonPropertyOrder({ OrgTechnicalContactType.JSON_PROPERTY_CONTACT_TYPE, OrgTechnicalContactType.JSON_PROPERTY_LINKS })
@JsonTypeName("orgTechnicalContactType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OrgTechnicalContactType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    private OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgTechnicalContactTypeLinks links;

    public OrgTechnicalContactType() {
    }

    public OrgTechnicalContactType contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgTechnicalContactType links(OrgTechnicalContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgTechnicalContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgTechnicalContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgTechnicalContactType orgTechnicalContactType = (OrgTechnicalContactType) o;
        return Objects.equals(this.contactType, orgTechnicalContactType.contactType)
                && Objects.equals(this.links, orgTechnicalContactType.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgTechnicalContactType {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/OrgTechnicalContactType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OrgContactType;
import com.okta.sdk.resource.model.OrgTechnicalContactTypeLinks;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Org technical contact
 */
@ApiModel(description = "Org technical contact")
@JsonPropertyOrder({ OrgTechnicalContactType.JSON_PROPERTY_CONTACT_TYPE, OrgTechnicalContactType.JSON_PROPERTY_LINKS })
@JsonTypeName("orgTechnicalContactType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class OrgTechnicalContactType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONTACT_TYPE = "contactType";
    private OrgContactType contactType;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private OrgTechnicalContactTypeLinks links;

    public OrgTechnicalContactType() {
    }

    public OrgTechnicalContactType contactType(OrgContactType contactType) {

        this.contactType = contactType;
        return this;
    }

    /**
     * Get contactType
     *
     * @return contactType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgContactType getContactType() {
        return contactType;
    }

    @JsonProperty(JSON_PROPERTY_CONTACT_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setContactType(OrgContactType contactType) {
        this.contactType = contactType;
    }

    public OrgTechnicalContactType links(OrgTechnicalContactTypeLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OrgTechnicalContactTypeLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(OrgTechnicalContactTypeLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OrgTechnicalContactType orgTechnicalContactType = (OrgTechnicalContactType) o;
        return Objects.equals(this.contactType, orgTechnicalContactType.contactType)
                && Objects.equals(this.links, orgTechnicalContactType.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(contactType, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OrgTechnicalContactType {\n");
        sb.append("    contactType: ").append(toIndentedString(contactType)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
